Class: Google::Apps::Meet::V2beta::ConferenceRecord
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2beta::ConferenceRecord
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2beta/resource.rb
Overview
Single instance of a meeting held in a space.
Instance Attribute Summary collapse
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#space ⇒ ::String
readonly
Output only.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the conference ended. Set for past conferences. Unset if the conference is ongoing.
340 341 342 343 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 340 class ConferenceRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#expire_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Server enforced expiration time for when this conference record resource is deleted. The resource is deleted 30 days after the conference ends.
340 341 342 343 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 340 class ConferenceRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. Resource name of the conference record.
Format: conferenceRecords/{conference_record} where {conference_record}
is a unique ID for each instance of a call within a space.
340 341 342 343 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 340 class ConferenceRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#space ⇒ ::String (readonly)
Returns Output only. The space where the conference was held.
340 341 342 343 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 340 class ConferenceRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the conference started. Always set.
340 341 342 343 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 340 class ConferenceRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |