Class: Google::Apps::Meet::V2beta::DriveDestination
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2beta::DriveDestination
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2beta/resource.rb
Overview
Export location where a recording file is saved in Google Drive.
Instance Attribute Summary collapse
-
#export_uri ⇒ ::String
readonly
Output only.
-
#file ⇒ ::String
readonly
Output only.
Instance Attribute Details
#export_uri ⇒ ::String (readonly)
Returns Output only. Link used to play back the recording file in the browser. For
example, https://drive.google.com/file/d/{$fileId}/view.
488 489 490 491 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 488 class DriveDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#file ⇒ ::String (readonly)
Returns Output only. The fileId for the underlying MP4 file. For example,
"1kuceFZohVoCh6FulBHxwy6I15Ogpc4hP". Use $ GET
https://www.googleapis.com/drive/v3/files/\\{$fileId}?alt=media to download
the blob. For more information, see
https://developers.google.com/drive/api/v3/reference/files/get.
488 489 490 491 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 488 class DriveDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |