Class: Google::Apps::Meet::V2beta::GetSpaceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/meet/v2beta/service.rb

Overview

Request to get a space.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Resource name of the space.

Format: spaces/{space} or spaces/{meetingCode}.

{space} is the resource identifier for the space. It's a unique, server-generated ID and is case sensitive. For example, jQCFfuBOdN5z.

{meetingCode} is an alias for the space. It's a typeable, unique character string and is non-case sensitive. For example, abc-mnop-xyz. The maximum length is 128 characters.

A meetingCode shouldn't be stored long term as it can become dissociated from a meeting space and can be reused for different meeting spaces in the future. Generally, a meetingCode expires 365 days after last use. For more information, see Learn about meeting codes in Google Meet.

For more information, see How Meet identifies a meeting space.

Returns:

  • (::String)

    Required. Resource name of the space.

    Format: spaces/{space} or spaces/{meetingCode}.

    {space} is the resource identifier for the space. It's a unique, server-generated ID and is case sensitive. For example, jQCFfuBOdN5z.

    {meetingCode} is an alias for the space. It's a typeable, unique character string and is non-case sensitive. For example, abc-mnop-xyz. The maximum length is 128 characters.

    A meetingCode shouldn't be stored long term as it can become dissociated from a meeting space and can be reused for different meeting spaces in the future. Generally, a meetingCode expires 365 days after last use. For more information, see Learn about meeting codes in Google Meet.

    For more information, see How Meet identifies a meeting space.



56
57
58
59
# File 'proto_docs/google/apps/meet/v2beta/service.rb', line 56

class GetSpaceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end