Class: Google::Apps::Meet::V2beta::ListConferenceRecordsResponse
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2beta::ListConferenceRecordsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2beta/service.rb
Overview
Response of ListConferenceRecords method.
Instance Attribute Summary collapse
-
#conference_records ⇒ ::Array<::Google::Apps::Meet::V2beta::ConferenceRecord>
List of conferences in one page.
-
#next_page_token ⇒ ::String
Token to be circulated back for further List call if current List does NOT include all the Conferences.
Instance Attribute Details
#conference_records ⇒ ::Array<::Google::Apps::Meet::V2beta::ConferenceRecord>
Returns List of conferences in one page.
246 247 248 249 |
# File 'proto_docs/google/apps/meet/v2beta/service.rb', line 246 class ListConferenceRecordsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns Token to be circulated back for further List call if current List does NOT include all the Conferences. Unset if all conferences have been returned.
246 247 248 249 |
# File 'proto_docs/google/apps/meet/v2beta/service.rb', line 246 class ListConferenceRecordsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |