Class: Google::Apps::Meet::V2beta::ListMembersResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/meet/v2beta/service.rb

Overview

Response of list members.

Instance Attribute Summary collapse

Instance Attribute Details

#members::Array<::Google::Apps::Meet::V2beta::Member>

Returns The list of members for the current page.

Returns:



182
183
184
185
# File 'proto_docs/google/apps/meet/v2beta/service.rb', line 182

class ListMembersResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns Token to be circulated back for further list call if current list doesn't include all the members. Unset if all members are returned.

Returns:

  • (::String)

    Token to be circulated back for further list call if current list doesn't include all the members. Unset if all members are returned.



182
183
184
185
# File 'proto_docs/google/apps/meet/v2beta/service.rb', line 182

class ListMembersResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end