Class: Google::Apps::Meet::V2beta::ListTranscriptEntriesResponse
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2beta::ListTranscriptEntriesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2beta/service.rb
Overview
Response for ListTranscriptEntries method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
Token to be circulated back for further List call if current List doesn't include all the transcript entries.
-
#transcript_entries ⇒ ::Array<::Google::Apps::Meet::V2beta::TranscriptEntry>
List of TranscriptEntries in one page.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns Token to be circulated back for further List call if current List doesn't include all the transcript entries. Unset if all entries are returned.
481 482 483 484 |
# File 'proto_docs/google/apps/meet/v2beta/service.rb', line 481 class ListTranscriptEntriesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transcript_entries ⇒ ::Array<::Google::Apps::Meet::V2beta::TranscriptEntry>
Returns List of TranscriptEntries in one page.
481 482 483 484 |
# File 'proto_docs/google/apps/meet/v2beta/service.rb', line 481 class ListTranscriptEntriesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |