Class: Google::Apps::Meet::V2beta::Recording

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/meet/v2beta/resource.rb

Overview

Metadata about a recording created during a conference.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#drive_destination::Google::Apps::Meet::V2beta::DriveDestination (readonly)

Returns Output only. Recording is saved to Google Drive as an MP4 file. The drive_destination includes the Drive fileId that can be used to download the file using the files.get method of the Drive API.

Returns:

  • (::Google::Apps::Meet::V2beta::DriveDestination)

    Output only. Recording is saved to Google Drive as an MP4 file. The drive_destination includes the Drive fileId that can be used to download the file using the files.get method of the Drive API.



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 455

class Recording
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the recording session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active recording session has started.
    STARTED = 1

    # This recording session has ended, but the recording file hasn't been
    # generated yet.
    ENDED = 2

    # Recording file is generated and ready to download.
    FILE_GENERATED = 3
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the recording ended.

Returns:



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 455

class Recording
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the recording session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active recording session has started.
    STARTED = 1

    # This recording session has ended, but the recording file hasn't been
    # generated yet.
    ENDED = 2

    # Recording file is generated and ready to download.
    FILE_GENERATED = 3
  end
end

#name::String (readonly)

Returns Output only. Resource name of the recording. Format: conferenceRecords/{conference_record}/recordings/{recording} where {recording} is a 1:1 mapping to each unique recording session during the conference.

Returns:

  • (::String)

    Output only. Resource name of the recording. Format: conferenceRecords/{conference_record}/recordings/{recording} where {recording} is a 1:1 mapping to each unique recording session during the conference.



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 455

class Recording
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the recording session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active recording session has started.
    STARTED = 1

    # This recording session has ended, but the recording file hasn't been
    # generated yet.
    ENDED = 2

    # Recording file is generated and ready to download.
    FILE_GENERATED = 3
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the recording started.

Returns:



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 455

class Recording
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the recording session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active recording session has started.
    STARTED = 1

    # This recording session has ended, but the recording file hasn't been
    # generated yet.
    ENDED = 2

    # Recording file is generated and ready to download.
    FILE_GENERATED = 3
  end
end

#state::Google::Apps::Meet::V2beta::Recording::State (readonly)

Returns Output only. Current state.

Returns:



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 455

class Recording
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the recording session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active recording session has started.
    STARTED = 1

    # This recording session has ended, but the recording file hasn't been
    # generated yet.
    ENDED = 2

    # Recording file is generated and ready to download.
    FILE_GENERATED = 3
  end
end