Class: Google::Apps::Meet::V2beta::SpaceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/meet/v2beta/resource.rb

Overview

The configuration pertaining to a meeting space.

Defined Under Namespace

Modules: AccessType, AttendanceReportGenerationType, EntryPointAccess, Moderation Classes: ArtifactConfig, ModerationRestrictions

Instance Attribute Summary collapse

Instance Attribute Details

#access_type::Google::Apps::Meet::V2beta::SpaceConfig::AccessType

Returns Access type of the meeting space that determines who can join without knocking. Default: The user's default access settings. Controlled by the user's admin for enterprise users or RESTRICTED.

Returns:



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 103

class SpaceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines restrictions for features when the meeting is moderated.
  # @!attribute [rw] chat_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send chat messages in the meeting space.
  # @!attribute [rw] reaction_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send reactions in the meeting space.
  # @!attribute [rw] present_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to share their screen in the meeting space.
  # @!attribute [rw] default_join_as_viewer_type
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::DefaultJoinAsViewerType]
  #     Defines whether to restrict the default role assigned to users as viewer.
  class ModerationRestrictions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Determines who has permission to use a particular feature.
    module RestrictionType
      # Default value specified by user policy.
      # This should never be returned.
      RESTRICTION_TYPE_UNSPECIFIED = 0

      # Meeting owner and co-host have the permission.
      HOSTS_ONLY = 1

      # All Participants have permissions.
      NO_RESTRICTION = 2
    end

    # By default users will join as contributors. Hosts can restrict users to
    # join as viewers.
    # Note: If an explicit role is set for a users in the Member resource, the
    # user will join as that role.
    module DefaultJoinAsViewerType
      # Default value specified by user policy.
      # This should never be returned.
      DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

      # Users will by default join as viewers.
      ON = 1

      # Users will by default join as contributors.
      OFF = 2
    end
  end

  # Configuration related to meeting artifacts potentially generated by this
  # meeting space.
  # @!attribute [rw] recording_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::RecordingConfig]
  #     Configuration for recording.
  # @!attribute [rw] transcription_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::TranscriptionConfig]
  #     Configuration for auto-transcript.
  # @!attribute [rw] smart_notes_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::SmartNotesConfig]
  #     Configuration for auto-smart-notes.
  class ArtifactConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Configuration related to recording in a meeting space.
    # @!attribute [rw] auto_recording_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether a meeting space is automatically recorded when someone
    #     with the privilege to record joins the meeting.
    class RecordingConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to transcription in a meeting space.
    # @!attribute [rw] auto_transcription_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether the content of a meeting is automatically transcribed
    #     when someone with the privilege to transcribe joins the meeting.
    class TranscriptionConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to smart notes in a meeting space. More
    # details about smart notes
    # https://support.google.com/meet/answer/14754931?hl=en.
    # @!attribute [rw] auto_smart_notes_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether to automatically generate a summary and recap of the
    #     meeting for all invitees in the organization when someone with the
    #     privilege to enable smart notes joins the meeting.
    class SmartNotesConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Determines whether an artifact can be automatically generated in the
    # meeting space.
    module AutoGenerationType
      # Default value specified by user policy.
      # This should never be returned.
      AUTO_GENERATION_TYPE_UNSPECIFIED = 0

      # The artifact is generated automatically.
      ON = 1

      # The artifact is not generated automatically.
      OFF = 2
    end
  end

  # Possible access types for a meeting space.
  module AccessType
    # Default value specified by the user's organization.
    # Note: This is never returned, as the configured access type is
    # returned instead.
    ACCESS_TYPE_UNSPECIFIED = 0

    # Anyone with the join information (for example, the URL or phone access
    # information) can join without knocking.
    OPEN = 1

    # Members of the host's organization, invited external users, and dial-in
    # users can join without knocking. Everyone else must knock.
    TRUSTED = 2

    # Only invitees can join without knocking. Everyone else must knock.
    RESTRICTED = 3
  end

  # Entry points that can be used to join a meeting.  Example:
  # `meet.google.com`, the Meet Embed SDK Web, or a mobile application.
  module EntryPointAccess
    # Unused.
    ENTRY_POINT_ACCESS_UNSPECIFIED = 0

    # All entry points are allowed.
    ALL = 1

    # Only entry points owned by the Google Cloud project that created the
    # space can be used to join meetings in this space. Apps can use the Meet
    # Embed SDK Web or mobile Meet SDKs to create owned entry points.
    CREATOR_APP_ONLY = 2
  end

  # The moderation mode for a meeting. When the moderation mode is on, the
  # meeting owner has more control over the meeting with features such as
  # co-host management (see message Member) and feature restrictions (see
  # message ModerationRestrictions).
  module Moderation
    # Moderation type is not specified. This is used to indicate the user
    # hasn't specified any value as the user does not intend to update the
    # state. Users are not allowed to set the value as unspecified.
    MODERATION_UNSPECIFIED = 0

    # Moderation is off.
    OFF = 1

    # Moderation is on.
    ON = 2
  end

  # Possible states of whether attendance report is enabled for the meeting
  # space.
  module AttendanceReportGenerationType
    # Default value specified by user policy.
    # This should never be returned.
    ATTENDANCE_REPORT_GENERATION_TYPE_UNSPECIFIED = 0

    # Attendance report will be generated and sent to drive/email.
    GENERATE_REPORT = 1

    # Attendance report will not be generated.
    DO_NOT_GENERATE = 2
  end
end

#artifact_config::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig

Returns Developer Preview: Configuration pertaining to the auto-generated artifacts that the meeting supports.

Returns:



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 103

class SpaceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines restrictions for features when the meeting is moderated.
  # @!attribute [rw] chat_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send chat messages in the meeting space.
  # @!attribute [rw] reaction_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send reactions in the meeting space.
  # @!attribute [rw] present_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to share their screen in the meeting space.
  # @!attribute [rw] default_join_as_viewer_type
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::DefaultJoinAsViewerType]
  #     Defines whether to restrict the default role assigned to users as viewer.
  class ModerationRestrictions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Determines who has permission to use a particular feature.
    module RestrictionType
      # Default value specified by user policy.
      # This should never be returned.
      RESTRICTION_TYPE_UNSPECIFIED = 0

      # Meeting owner and co-host have the permission.
      HOSTS_ONLY = 1

      # All Participants have permissions.
      NO_RESTRICTION = 2
    end

    # By default users will join as contributors. Hosts can restrict users to
    # join as viewers.
    # Note: If an explicit role is set for a users in the Member resource, the
    # user will join as that role.
    module DefaultJoinAsViewerType
      # Default value specified by user policy.
      # This should never be returned.
      DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

      # Users will by default join as viewers.
      ON = 1

      # Users will by default join as contributors.
      OFF = 2
    end
  end

  # Configuration related to meeting artifacts potentially generated by this
  # meeting space.
  # @!attribute [rw] recording_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::RecordingConfig]
  #     Configuration for recording.
  # @!attribute [rw] transcription_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::TranscriptionConfig]
  #     Configuration for auto-transcript.
  # @!attribute [rw] smart_notes_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::SmartNotesConfig]
  #     Configuration for auto-smart-notes.
  class ArtifactConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Configuration related to recording in a meeting space.
    # @!attribute [rw] auto_recording_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether a meeting space is automatically recorded when someone
    #     with the privilege to record joins the meeting.
    class RecordingConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to transcription in a meeting space.
    # @!attribute [rw] auto_transcription_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether the content of a meeting is automatically transcribed
    #     when someone with the privilege to transcribe joins the meeting.
    class TranscriptionConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to smart notes in a meeting space. More
    # details about smart notes
    # https://support.google.com/meet/answer/14754931?hl=en.
    # @!attribute [rw] auto_smart_notes_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether to automatically generate a summary and recap of the
    #     meeting for all invitees in the organization when someone with the
    #     privilege to enable smart notes joins the meeting.
    class SmartNotesConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Determines whether an artifact can be automatically generated in the
    # meeting space.
    module AutoGenerationType
      # Default value specified by user policy.
      # This should never be returned.
      AUTO_GENERATION_TYPE_UNSPECIFIED = 0

      # The artifact is generated automatically.
      ON = 1

      # The artifact is not generated automatically.
      OFF = 2
    end
  end

  # Possible access types for a meeting space.
  module AccessType
    # Default value specified by the user's organization.
    # Note: This is never returned, as the configured access type is
    # returned instead.
    ACCESS_TYPE_UNSPECIFIED = 0

    # Anyone with the join information (for example, the URL or phone access
    # information) can join without knocking.
    OPEN = 1

    # Members of the host's organization, invited external users, and dial-in
    # users can join without knocking. Everyone else must knock.
    TRUSTED = 2

    # Only invitees can join without knocking. Everyone else must knock.
    RESTRICTED = 3
  end

  # Entry points that can be used to join a meeting.  Example:
  # `meet.google.com`, the Meet Embed SDK Web, or a mobile application.
  module EntryPointAccess
    # Unused.
    ENTRY_POINT_ACCESS_UNSPECIFIED = 0

    # All entry points are allowed.
    ALL = 1

    # Only entry points owned by the Google Cloud project that created the
    # space can be used to join meetings in this space. Apps can use the Meet
    # Embed SDK Web or mobile Meet SDKs to create owned entry points.
    CREATOR_APP_ONLY = 2
  end

  # The moderation mode for a meeting. When the moderation mode is on, the
  # meeting owner has more control over the meeting with features such as
  # co-host management (see message Member) and feature restrictions (see
  # message ModerationRestrictions).
  module Moderation
    # Moderation type is not specified. This is used to indicate the user
    # hasn't specified any value as the user does not intend to update the
    # state. Users are not allowed to set the value as unspecified.
    MODERATION_UNSPECIFIED = 0

    # Moderation is off.
    OFF = 1

    # Moderation is on.
    ON = 2
  end

  # Possible states of whether attendance report is enabled for the meeting
  # space.
  module AttendanceReportGenerationType
    # Default value specified by user policy.
    # This should never be returned.
    ATTENDANCE_REPORT_GENERATION_TYPE_UNSPECIFIED = 0

    # Attendance report will be generated and sent to drive/email.
    GENERATE_REPORT = 1

    # Attendance report will not be generated.
    DO_NOT_GENERATE = 2
  end
end

#attendance_report_generation_type::Google::Apps::Meet::V2beta::SpaceConfig::AttendanceReportGenerationType

Returns Developer Preview: Whether attendance report is enabled for the meeting space.

Returns:



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 103

class SpaceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines restrictions for features when the meeting is moderated.
  # @!attribute [rw] chat_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send chat messages in the meeting space.
  # @!attribute [rw] reaction_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send reactions in the meeting space.
  # @!attribute [rw] present_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to share their screen in the meeting space.
  # @!attribute [rw] default_join_as_viewer_type
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::DefaultJoinAsViewerType]
  #     Defines whether to restrict the default role assigned to users as viewer.
  class ModerationRestrictions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Determines who has permission to use a particular feature.
    module RestrictionType
      # Default value specified by user policy.
      # This should never be returned.
      RESTRICTION_TYPE_UNSPECIFIED = 0

      # Meeting owner and co-host have the permission.
      HOSTS_ONLY = 1

      # All Participants have permissions.
      NO_RESTRICTION = 2
    end

    # By default users will join as contributors. Hosts can restrict users to
    # join as viewers.
    # Note: If an explicit role is set for a users in the Member resource, the
    # user will join as that role.
    module DefaultJoinAsViewerType
      # Default value specified by user policy.
      # This should never be returned.
      DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

      # Users will by default join as viewers.
      ON = 1

      # Users will by default join as contributors.
      OFF = 2
    end
  end

  # Configuration related to meeting artifacts potentially generated by this
  # meeting space.
  # @!attribute [rw] recording_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::RecordingConfig]
  #     Configuration for recording.
  # @!attribute [rw] transcription_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::TranscriptionConfig]
  #     Configuration for auto-transcript.
  # @!attribute [rw] smart_notes_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::SmartNotesConfig]
  #     Configuration for auto-smart-notes.
  class ArtifactConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Configuration related to recording in a meeting space.
    # @!attribute [rw] auto_recording_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether a meeting space is automatically recorded when someone
    #     with the privilege to record joins the meeting.
    class RecordingConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to transcription in a meeting space.
    # @!attribute [rw] auto_transcription_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether the content of a meeting is automatically transcribed
    #     when someone with the privilege to transcribe joins the meeting.
    class TranscriptionConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to smart notes in a meeting space. More
    # details about smart notes
    # https://support.google.com/meet/answer/14754931?hl=en.
    # @!attribute [rw] auto_smart_notes_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether to automatically generate a summary and recap of the
    #     meeting for all invitees in the organization when someone with the
    #     privilege to enable smart notes joins the meeting.
    class SmartNotesConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Determines whether an artifact can be automatically generated in the
    # meeting space.
    module AutoGenerationType
      # Default value specified by user policy.
      # This should never be returned.
      AUTO_GENERATION_TYPE_UNSPECIFIED = 0

      # The artifact is generated automatically.
      ON = 1

      # The artifact is not generated automatically.
      OFF = 2
    end
  end

  # Possible access types for a meeting space.
  module AccessType
    # Default value specified by the user's organization.
    # Note: This is never returned, as the configured access type is
    # returned instead.
    ACCESS_TYPE_UNSPECIFIED = 0

    # Anyone with the join information (for example, the URL or phone access
    # information) can join without knocking.
    OPEN = 1

    # Members of the host's organization, invited external users, and dial-in
    # users can join without knocking. Everyone else must knock.
    TRUSTED = 2

    # Only invitees can join without knocking. Everyone else must knock.
    RESTRICTED = 3
  end

  # Entry points that can be used to join a meeting.  Example:
  # `meet.google.com`, the Meet Embed SDK Web, or a mobile application.
  module EntryPointAccess
    # Unused.
    ENTRY_POINT_ACCESS_UNSPECIFIED = 0

    # All entry points are allowed.
    ALL = 1

    # Only entry points owned by the Google Cloud project that created the
    # space can be used to join meetings in this space. Apps can use the Meet
    # Embed SDK Web or mobile Meet SDKs to create owned entry points.
    CREATOR_APP_ONLY = 2
  end

  # The moderation mode for a meeting. When the moderation mode is on, the
  # meeting owner has more control over the meeting with features such as
  # co-host management (see message Member) and feature restrictions (see
  # message ModerationRestrictions).
  module Moderation
    # Moderation type is not specified. This is used to indicate the user
    # hasn't specified any value as the user does not intend to update the
    # state. Users are not allowed to set the value as unspecified.
    MODERATION_UNSPECIFIED = 0

    # Moderation is off.
    OFF = 1

    # Moderation is on.
    ON = 2
  end

  # Possible states of whether attendance report is enabled for the meeting
  # space.
  module AttendanceReportGenerationType
    # Default value specified by user policy.
    # This should never be returned.
    ATTENDANCE_REPORT_GENERATION_TYPE_UNSPECIFIED = 0

    # Attendance report will be generated and sent to drive/email.
    GENERATE_REPORT = 1

    # Attendance report will not be generated.
    DO_NOT_GENERATE = 2
  end
end

#entry_point_access::Google::Apps::Meet::V2beta::SpaceConfig::EntryPointAccess

Returns Defines the entry points that can be used to join meetings hosted in this meeting space. Default: EntryPointAccess.ALL.

Returns:



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 103

class SpaceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines restrictions for features when the meeting is moderated.
  # @!attribute [rw] chat_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send chat messages in the meeting space.
  # @!attribute [rw] reaction_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send reactions in the meeting space.
  # @!attribute [rw] present_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to share their screen in the meeting space.
  # @!attribute [rw] default_join_as_viewer_type
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::DefaultJoinAsViewerType]
  #     Defines whether to restrict the default role assigned to users as viewer.
  class ModerationRestrictions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Determines who has permission to use a particular feature.
    module RestrictionType
      # Default value specified by user policy.
      # This should never be returned.
      RESTRICTION_TYPE_UNSPECIFIED = 0

      # Meeting owner and co-host have the permission.
      HOSTS_ONLY = 1

      # All Participants have permissions.
      NO_RESTRICTION = 2
    end

    # By default users will join as contributors. Hosts can restrict users to
    # join as viewers.
    # Note: If an explicit role is set for a users in the Member resource, the
    # user will join as that role.
    module DefaultJoinAsViewerType
      # Default value specified by user policy.
      # This should never be returned.
      DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

      # Users will by default join as viewers.
      ON = 1

      # Users will by default join as contributors.
      OFF = 2
    end
  end

  # Configuration related to meeting artifacts potentially generated by this
  # meeting space.
  # @!attribute [rw] recording_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::RecordingConfig]
  #     Configuration for recording.
  # @!attribute [rw] transcription_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::TranscriptionConfig]
  #     Configuration for auto-transcript.
  # @!attribute [rw] smart_notes_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::SmartNotesConfig]
  #     Configuration for auto-smart-notes.
  class ArtifactConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Configuration related to recording in a meeting space.
    # @!attribute [rw] auto_recording_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether a meeting space is automatically recorded when someone
    #     with the privilege to record joins the meeting.
    class RecordingConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to transcription in a meeting space.
    # @!attribute [rw] auto_transcription_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether the content of a meeting is automatically transcribed
    #     when someone with the privilege to transcribe joins the meeting.
    class TranscriptionConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to smart notes in a meeting space. More
    # details about smart notes
    # https://support.google.com/meet/answer/14754931?hl=en.
    # @!attribute [rw] auto_smart_notes_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether to automatically generate a summary and recap of the
    #     meeting for all invitees in the organization when someone with the
    #     privilege to enable smart notes joins the meeting.
    class SmartNotesConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Determines whether an artifact can be automatically generated in the
    # meeting space.
    module AutoGenerationType
      # Default value specified by user policy.
      # This should never be returned.
      AUTO_GENERATION_TYPE_UNSPECIFIED = 0

      # The artifact is generated automatically.
      ON = 1

      # The artifact is not generated automatically.
      OFF = 2
    end
  end

  # Possible access types for a meeting space.
  module AccessType
    # Default value specified by the user's organization.
    # Note: This is never returned, as the configured access type is
    # returned instead.
    ACCESS_TYPE_UNSPECIFIED = 0

    # Anyone with the join information (for example, the URL or phone access
    # information) can join without knocking.
    OPEN = 1

    # Members of the host's organization, invited external users, and dial-in
    # users can join without knocking. Everyone else must knock.
    TRUSTED = 2

    # Only invitees can join without knocking. Everyone else must knock.
    RESTRICTED = 3
  end

  # Entry points that can be used to join a meeting.  Example:
  # `meet.google.com`, the Meet Embed SDK Web, or a mobile application.
  module EntryPointAccess
    # Unused.
    ENTRY_POINT_ACCESS_UNSPECIFIED = 0

    # All entry points are allowed.
    ALL = 1

    # Only entry points owned by the Google Cloud project that created the
    # space can be used to join meetings in this space. Apps can use the Meet
    # Embed SDK Web or mobile Meet SDKs to create owned entry points.
    CREATOR_APP_ONLY = 2
  end

  # The moderation mode for a meeting. When the moderation mode is on, the
  # meeting owner has more control over the meeting with features such as
  # co-host management (see message Member) and feature restrictions (see
  # message ModerationRestrictions).
  module Moderation
    # Moderation type is not specified. This is used to indicate the user
    # hasn't specified any value as the user does not intend to update the
    # state. Users are not allowed to set the value as unspecified.
    MODERATION_UNSPECIFIED = 0

    # Moderation is off.
    OFF = 1

    # Moderation is on.
    ON = 2
  end

  # Possible states of whether attendance report is enabled for the meeting
  # space.
  module AttendanceReportGenerationType
    # Default value specified by user policy.
    # This should never be returned.
    ATTENDANCE_REPORT_GENERATION_TYPE_UNSPECIFIED = 0

    # Attendance report will be generated and sent to drive/email.
    GENERATE_REPORT = 1

    # Attendance report will not be generated.
    DO_NOT_GENERATE = 2
  end
end

#moderation::Google::Apps::Meet::V2beta::SpaceConfig::Moderation

Returns Developer Preview: The pre-configured moderation mode for the Meeting. Default: Controlled by the user's policies.

Returns:



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 103

class SpaceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines restrictions for features when the meeting is moderated.
  # @!attribute [rw] chat_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send chat messages in the meeting space.
  # @!attribute [rw] reaction_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send reactions in the meeting space.
  # @!attribute [rw] present_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to share their screen in the meeting space.
  # @!attribute [rw] default_join_as_viewer_type
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::DefaultJoinAsViewerType]
  #     Defines whether to restrict the default role assigned to users as viewer.
  class ModerationRestrictions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Determines who has permission to use a particular feature.
    module RestrictionType
      # Default value specified by user policy.
      # This should never be returned.
      RESTRICTION_TYPE_UNSPECIFIED = 0

      # Meeting owner and co-host have the permission.
      HOSTS_ONLY = 1

      # All Participants have permissions.
      NO_RESTRICTION = 2
    end

    # By default users will join as contributors. Hosts can restrict users to
    # join as viewers.
    # Note: If an explicit role is set for a users in the Member resource, the
    # user will join as that role.
    module DefaultJoinAsViewerType
      # Default value specified by user policy.
      # This should never be returned.
      DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

      # Users will by default join as viewers.
      ON = 1

      # Users will by default join as contributors.
      OFF = 2
    end
  end

  # Configuration related to meeting artifacts potentially generated by this
  # meeting space.
  # @!attribute [rw] recording_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::RecordingConfig]
  #     Configuration for recording.
  # @!attribute [rw] transcription_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::TranscriptionConfig]
  #     Configuration for auto-transcript.
  # @!attribute [rw] smart_notes_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::SmartNotesConfig]
  #     Configuration for auto-smart-notes.
  class ArtifactConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Configuration related to recording in a meeting space.
    # @!attribute [rw] auto_recording_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether a meeting space is automatically recorded when someone
    #     with the privilege to record joins the meeting.
    class RecordingConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to transcription in a meeting space.
    # @!attribute [rw] auto_transcription_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether the content of a meeting is automatically transcribed
    #     when someone with the privilege to transcribe joins the meeting.
    class TranscriptionConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to smart notes in a meeting space. More
    # details about smart notes
    # https://support.google.com/meet/answer/14754931?hl=en.
    # @!attribute [rw] auto_smart_notes_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether to automatically generate a summary and recap of the
    #     meeting for all invitees in the organization when someone with the
    #     privilege to enable smart notes joins the meeting.
    class SmartNotesConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Determines whether an artifact can be automatically generated in the
    # meeting space.
    module AutoGenerationType
      # Default value specified by user policy.
      # This should never be returned.
      AUTO_GENERATION_TYPE_UNSPECIFIED = 0

      # The artifact is generated automatically.
      ON = 1

      # The artifact is not generated automatically.
      OFF = 2
    end
  end

  # Possible access types for a meeting space.
  module AccessType
    # Default value specified by the user's organization.
    # Note: This is never returned, as the configured access type is
    # returned instead.
    ACCESS_TYPE_UNSPECIFIED = 0

    # Anyone with the join information (for example, the URL or phone access
    # information) can join without knocking.
    OPEN = 1

    # Members of the host's organization, invited external users, and dial-in
    # users can join without knocking. Everyone else must knock.
    TRUSTED = 2

    # Only invitees can join without knocking. Everyone else must knock.
    RESTRICTED = 3
  end

  # Entry points that can be used to join a meeting.  Example:
  # `meet.google.com`, the Meet Embed SDK Web, or a mobile application.
  module EntryPointAccess
    # Unused.
    ENTRY_POINT_ACCESS_UNSPECIFIED = 0

    # All entry points are allowed.
    ALL = 1

    # Only entry points owned by the Google Cloud project that created the
    # space can be used to join meetings in this space. Apps can use the Meet
    # Embed SDK Web or mobile Meet SDKs to create owned entry points.
    CREATOR_APP_ONLY = 2
  end

  # The moderation mode for a meeting. When the moderation mode is on, the
  # meeting owner has more control over the meeting with features such as
  # co-host management (see message Member) and feature restrictions (see
  # message ModerationRestrictions).
  module Moderation
    # Moderation type is not specified. This is used to indicate the user
    # hasn't specified any value as the user does not intend to update the
    # state. Users are not allowed to set the value as unspecified.
    MODERATION_UNSPECIFIED = 0

    # Moderation is off.
    OFF = 1

    # Moderation is on.
    ON = 2
  end

  # Possible states of whether attendance report is enabled for the meeting
  # space.
  module AttendanceReportGenerationType
    # Default value specified by user policy.
    # This should never be returned.
    ATTENDANCE_REPORT_GENERATION_TYPE_UNSPECIFIED = 0

    # Attendance report will be generated and sent to drive/email.
    GENERATE_REPORT = 1

    # Attendance report will not be generated.
    DO_NOT_GENERATE = 2
  end
end

#moderation_restrictions::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions

Returns Developer Preview: When moderation.ON, these restrictions go into effect for the meeting. When moderation.OFF, will be reset to default ModerationRestrictions.

Returns:



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 103

class SpaceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines restrictions for features when the meeting is moderated.
  # @!attribute [rw] chat_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send chat messages in the meeting space.
  # @!attribute [rw] reaction_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to send reactions in the meeting space.
  # @!attribute [rw] present_restriction
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType]
  #     Defines who has permission to share their screen in the meeting space.
  # @!attribute [rw] default_join_as_viewer_type
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::DefaultJoinAsViewerType]
  #     Defines whether to restrict the default role assigned to users as viewer.
  class ModerationRestrictions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Determines who has permission to use a particular feature.
    module RestrictionType
      # Default value specified by user policy.
      # This should never be returned.
      RESTRICTION_TYPE_UNSPECIFIED = 0

      # Meeting owner and co-host have the permission.
      HOSTS_ONLY = 1

      # All Participants have permissions.
      NO_RESTRICTION = 2
    end

    # By default users will join as contributors. Hosts can restrict users to
    # join as viewers.
    # Note: If an explicit role is set for a users in the Member resource, the
    # user will join as that role.
    module DefaultJoinAsViewerType
      # Default value specified by user policy.
      # This should never be returned.
      DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

      # Users will by default join as viewers.
      ON = 1

      # Users will by default join as contributors.
      OFF = 2
    end
  end

  # Configuration related to meeting artifacts potentially generated by this
  # meeting space.
  # @!attribute [rw] recording_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::RecordingConfig]
  #     Configuration for recording.
  # @!attribute [rw] transcription_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::TranscriptionConfig]
  #     Configuration for auto-transcript.
  # @!attribute [rw] smart_notes_config
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::SmartNotesConfig]
  #     Configuration for auto-smart-notes.
  class ArtifactConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Configuration related to recording in a meeting space.
    # @!attribute [rw] auto_recording_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether a meeting space is automatically recorded when someone
    #     with the privilege to record joins the meeting.
    class RecordingConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to transcription in a meeting space.
    # @!attribute [rw] auto_transcription_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether the content of a meeting is automatically transcribed
    #     when someone with the privilege to transcribe joins the meeting.
    class TranscriptionConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Configuration related to smart notes in a meeting space. More
    # details about smart notes
    # https://support.google.com/meet/answer/14754931?hl=en.
    # @!attribute [rw] auto_smart_notes_generation
    #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
    #     Defines whether to automatically generate a summary and recap of the
    #     meeting for all invitees in the organization when someone with the
    #     privilege to enable smart notes joins the meeting.
    class SmartNotesConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Determines whether an artifact can be automatically generated in the
    # meeting space.
    module AutoGenerationType
      # Default value specified by user policy.
      # This should never be returned.
      AUTO_GENERATION_TYPE_UNSPECIFIED = 0

      # The artifact is generated automatically.
      ON = 1

      # The artifact is not generated automatically.
      OFF = 2
    end
  end

  # Possible access types for a meeting space.
  module AccessType
    # Default value specified by the user's organization.
    # Note: This is never returned, as the configured access type is
    # returned instead.
    ACCESS_TYPE_UNSPECIFIED = 0

    # Anyone with the join information (for example, the URL or phone access
    # information) can join without knocking.
    OPEN = 1

    # Members of the host's organization, invited external users, and dial-in
    # users can join without knocking. Everyone else must knock.
    TRUSTED = 2

    # Only invitees can join without knocking. Everyone else must knock.
    RESTRICTED = 3
  end

  # Entry points that can be used to join a meeting.  Example:
  # `meet.google.com`, the Meet Embed SDK Web, or a mobile application.
  module EntryPointAccess
    # Unused.
    ENTRY_POINT_ACCESS_UNSPECIFIED = 0

    # All entry points are allowed.
    ALL = 1

    # Only entry points owned by the Google Cloud project that created the
    # space can be used to join meetings in this space. Apps can use the Meet
    # Embed SDK Web or mobile Meet SDKs to create owned entry points.
    CREATOR_APP_ONLY = 2
  end

  # The moderation mode for a meeting. When the moderation mode is on, the
  # meeting owner has more control over the meeting with features such as
  # co-host management (see message Member) and feature restrictions (see
  # message ModerationRestrictions).
  module Moderation
    # Moderation type is not specified. This is used to indicate the user
    # hasn't specified any value as the user does not intend to update the
    # state. Users are not allowed to set the value as unspecified.
    MODERATION_UNSPECIFIED = 0

    # Moderation is off.
    OFF = 1

    # Moderation is on.
    ON = 2
  end

  # Possible states of whether attendance report is enabled for the meeting
  # space.
  module AttendanceReportGenerationType
    # Default value specified by user policy.
    # This should never be returned.
    ATTENDANCE_REPORT_GENERATION_TYPE_UNSPECIFIED = 0

    # Attendance report will be generated and sent to drive/email.
    GENERATE_REPORT = 1

    # Attendance report will not be generated.
    DO_NOT_GENERATE = 2
  end
end