Class: Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/meet/v2beta/resource.rb

Overview

Configuration related to meeting artifacts potentially generated by this meeting space.

Defined Under Namespace

Modules: AutoGenerationType Classes: RecordingConfig, SmartNotesConfig, TranscriptionConfig

Instance Attribute Summary collapse

Instance Attribute Details

#recording_config::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::RecordingConfig

Returns Configuration for recording.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 165

class ArtifactConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration related to recording in a meeting space.
  # @!attribute [rw] auto_recording_generation
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
  #     Defines whether a meeting space is automatically recorded when someone
  #     with the privilege to record joins the meeting.
  class RecordingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration related to transcription in a meeting space.
  # @!attribute [rw] auto_transcription_generation
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
  #     Defines whether the content of a meeting is automatically transcribed
  #     when someone with the privilege to transcribe joins the meeting.
  class TranscriptionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration related to smart notes in a meeting space. More
  # details about smart notes
  # https://support.google.com/meet/answer/14754931?hl=en.
  # @!attribute [rw] auto_smart_notes_generation
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
  #     Defines whether to automatically generate a summary and recap of the
  #     meeting for all invitees in the organization when someone with the
  #     privilege to enable smart notes joins the meeting.
  class SmartNotesConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Determines whether an artifact can be automatically generated in the
  # meeting space.
  module AutoGenerationType
    # Default value specified by user policy.
    # This should never be returned.
    AUTO_GENERATION_TYPE_UNSPECIFIED = 0

    # The artifact is generated automatically.
    ON = 1

    # The artifact is not generated automatically.
    OFF = 2
  end
end

#smart_notes_config::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::SmartNotesConfig

Returns Configuration for auto-smart-notes.

Returns:



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 165

class ArtifactConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration related to recording in a meeting space.
  # @!attribute [rw] auto_recording_generation
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
  #     Defines whether a meeting space is automatically recorded when someone
  #     with the privilege to record joins the meeting.
  class RecordingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration related to transcription in a meeting space.
  # @!attribute [rw] auto_transcription_generation
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
  #     Defines whether the content of a meeting is automatically transcribed
  #     when someone with the privilege to transcribe joins the meeting.
  class TranscriptionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration related to smart notes in a meeting space. More
  # details about smart notes
  # https://support.google.com/meet/answer/14754931?hl=en.
  # @!attribute [rw] auto_smart_notes_generation
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
  #     Defines whether to automatically generate a summary and recap of the
  #     meeting for all invitees in the organization when someone with the
  #     privilege to enable smart notes joins the meeting.
  class SmartNotesConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Determines whether an artifact can be automatically generated in the
  # meeting space.
  module AutoGenerationType
    # Default value specified by user policy.
    # This should never be returned.
    AUTO_GENERATION_TYPE_UNSPECIFIED = 0

    # The artifact is generated automatically.
    ON = 1

    # The artifact is not generated automatically.
    OFF = 2
  end
end

#transcription_config::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::TranscriptionConfig

Returns Configuration for auto-transcript.

Returns:



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 165

class ArtifactConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration related to recording in a meeting space.
  # @!attribute [rw] auto_recording_generation
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
  #     Defines whether a meeting space is automatically recorded when someone
  #     with the privilege to record joins the meeting.
  class RecordingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration related to transcription in a meeting space.
  # @!attribute [rw] auto_transcription_generation
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
  #     Defines whether the content of a meeting is automatically transcribed
  #     when someone with the privilege to transcribe joins the meeting.
  class TranscriptionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration related to smart notes in a meeting space. More
  # details about smart notes
  # https://support.google.com/meet/answer/14754931?hl=en.
  # @!attribute [rw] auto_smart_notes_generation
  #   @return [::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType]
  #     Defines whether to automatically generate a summary and recap of the
  #     meeting for all invitees in the organization when someone with the
  #     privilege to enable smart notes joins the meeting.
  class SmartNotesConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Determines whether an artifact can be automatically generated in the
  # meeting space.
  module AutoGenerationType
    # Default value specified by user policy.
    # This should never be returned.
    AUTO_GENERATION_TYPE_UNSPECIFIED = 0

    # The artifact is generated automatically.
    ON = 1

    # The artifact is not generated automatically.
    OFF = 2
  end
end