Class: Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::SmartNotesConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/meet/v2beta/resource.rb

Overview

Configuration related to smart notes in a meeting space. More details about smart notes https://support.google.com/meet/answer/14754931?hl=en.

Instance Attribute Summary collapse

Instance Attribute Details

#auto_smart_notes_generation::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType

Returns Defines whether to automatically generate a summary and recap of the meeting for all invitees in the organization when someone with the privilege to enable smart notes joins the meeting.

Returns:



197
198
199
200
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 197

class SmartNotesConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end