Module: Google::Apps::Meet::V2beta::SpaceConfig::Moderation
- Defined in:
- proto_docs/google/apps/meet/v2beta/resource.rb
Overview
The moderation mode for a meeting. When the moderation mode is on, the meeting owner has more control over the meeting with features such as co-host management (see message Member) and feature restrictions (see message ModerationRestrictions).
Constant Summary collapse
- MODERATION_UNSPECIFIED =
Moderation type is not specified. This is used to indicate the user hasn't specified any value as the user does not intend to update the state. Users are not allowed to set the value as unspecified.
0- OFF =
Moderation is off.
1- ON =
Moderation is on.
2