Class: Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/meet/v2beta/resource.rb

Overview

Defines restrictions for features when the meeting is moderated.

Defined Under Namespace

Modules: DefaultJoinAsViewerType, RestrictionType

Instance Attribute Summary collapse

Instance Attribute Details

#chat_restriction::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType

Returns Defines who has permission to send chat messages in the meeting space.

Returns:



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 120

class ModerationRestrictions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who has permission to use a particular feature.
  module RestrictionType
    # Default value specified by user policy.
    # This should never be returned.
    RESTRICTION_TYPE_UNSPECIFIED = 0

    # Meeting owner and co-host have the permission.
    HOSTS_ONLY = 1

    # All Participants have permissions.
    NO_RESTRICTION = 2
  end

  # By default users will join as contributors. Hosts can restrict users to
  # join as viewers.
  # Note: If an explicit role is set for a users in the Member resource, the
  # user will join as that role.
  module DefaultJoinAsViewerType
    # Default value specified by user policy.
    # This should never be returned.
    DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

    # Users will by default join as viewers.
    ON = 1

    # Users will by default join as contributors.
    OFF = 2
  end
end

#default_join_as_viewer_type::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::DefaultJoinAsViewerType

Returns Defines whether to restrict the default role assigned to users as viewer.

Returns:



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 120

class ModerationRestrictions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who has permission to use a particular feature.
  module RestrictionType
    # Default value specified by user policy.
    # This should never be returned.
    RESTRICTION_TYPE_UNSPECIFIED = 0

    # Meeting owner and co-host have the permission.
    HOSTS_ONLY = 1

    # All Participants have permissions.
    NO_RESTRICTION = 2
  end

  # By default users will join as contributors. Hosts can restrict users to
  # join as viewers.
  # Note: If an explicit role is set for a users in the Member resource, the
  # user will join as that role.
  module DefaultJoinAsViewerType
    # Default value specified by user policy.
    # This should never be returned.
    DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

    # Users will by default join as viewers.
    ON = 1

    # Users will by default join as contributors.
    OFF = 2
  end
end

#present_restriction::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType

Returns Defines who has permission to share their screen in the meeting space.

Returns:



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 120

class ModerationRestrictions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who has permission to use a particular feature.
  module RestrictionType
    # Default value specified by user policy.
    # This should never be returned.
    RESTRICTION_TYPE_UNSPECIFIED = 0

    # Meeting owner and co-host have the permission.
    HOSTS_ONLY = 1

    # All Participants have permissions.
    NO_RESTRICTION = 2
  end

  # By default users will join as contributors. Hosts can restrict users to
  # join as viewers.
  # Note: If an explicit role is set for a users in the Member resource, the
  # user will join as that role.
  module DefaultJoinAsViewerType
    # Default value specified by user policy.
    # This should never be returned.
    DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

    # Users will by default join as viewers.
    ON = 1

    # Users will by default join as contributors.
    OFF = 2
  end
end

#reaction_restriction::Google::Apps::Meet::V2beta::SpaceConfig::ModerationRestrictions::RestrictionType

Returns Defines who has permission to send reactions in the meeting space.

Returns:



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 120

class ModerationRestrictions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who has permission to use a particular feature.
  module RestrictionType
    # Default value specified by user policy.
    # This should never be returned.
    RESTRICTION_TYPE_UNSPECIFIED = 0

    # Meeting owner and co-host have the permission.
    HOSTS_ONLY = 1

    # All Participants have permissions.
    NO_RESTRICTION = 2
  end

  # By default users will join as contributors. Hosts can restrict users to
  # join as viewers.
  # Note: If an explicit role is set for a users in the Member resource, the
  # user will join as that role.
  module DefaultJoinAsViewerType
    # Default value specified by user policy.
    # This should never be returned.
    DEFAULT_JOIN_AS_VIEWER_TYPE_UNSPECIFIED = 0

    # Users will by default join as viewers.
    ON = 1

    # Users will by default join as contributors.
    OFF = 2
  end
end