Class: Google::Apps::Meet::V2beta::Transcript

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/apps/meet/v2beta/resource.rb

Overview

Metadata for a transcript generated from a conference. It refers to the ASR (Automatic Speech Recognition) result of user's speech during the conference.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#docs_destination::Google::Apps::Meet::V2beta::DocsDestination (readonly)

Returns Output only. Where the Google Docs transcript is saved.

Returns:



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 513

class Transcript
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the transcript session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active transcript session has started.
    STARTED = 1

    # This transcript session has ended, but the transcript file hasn't been
    # generated yet.
    ENDED = 2

    # Transcript file is generated and ready to download.
    FILE_GENERATED = 3
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the transcript stopped.

Returns:



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 513

class Transcript
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the transcript session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active transcript session has started.
    STARTED = 1

    # This transcript session has ended, but the transcript file hasn't been
    # generated yet.
    ENDED = 2

    # Transcript file is generated and ready to download.
    FILE_GENERATED = 3
  end
end

#name::String (readonly)

Returns Output only. Resource name of the transcript. Format: conferenceRecords/{conference_record}/transcripts/{transcript}, where {transcript} is a 1:1 mapping to each unique transcription session of the conference.

Returns:

  • (::String)

    Output only. Resource name of the transcript. Format: conferenceRecords/{conference_record}/transcripts/{transcript}, where {transcript} is a 1:1 mapping to each unique transcription session of the conference.



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 513

class Transcript
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the transcript session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active transcript session has started.
    STARTED = 1

    # This transcript session has ended, but the transcript file hasn't been
    # generated yet.
    ENDED = 2

    # Transcript file is generated and ready to download.
    FILE_GENERATED = 3
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the transcript started.

Returns:



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 513

class Transcript
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the transcript session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active transcript session has started.
    STARTED = 1

    # This transcript session has ended, but the transcript file hasn't been
    # generated yet.
    ENDED = 2

    # Transcript file is generated and ready to download.
    FILE_GENERATED = 3
  end
end

#state::Google::Apps::Meet::V2beta::Transcript::State (readonly)

Returns Output only. Current state.

Returns:



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 513

class Transcript
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Current state of the transcript session.
  module State
    # Default, never used.
    STATE_UNSPECIFIED = 0

    # An active transcript session has started.
    STARTED = 1

    # This transcript session has ended, but the transcript file hasn't been
    # generated yet.
    ENDED = 2

    # Transcript file is generated and ready to download.
    FILE_GENERATED = 3
  end
end