Class: Google::Apps::Meet::V2beta::Member
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2beta::Member
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2beta/resource.rb
Overview
Users who are configured to have a role in the space. These users can join the space without knocking.
Defined Under Namespace
Modules: Role
Instance Attribute Summary collapse
-
#email ⇒ ::String
Email for the member.
-
#name ⇒ ::String
Identifier.
-
#role ⇒ ::Google::Apps::Meet::V2beta::Member::Role
The meeting role assigned to the member.
-
#user ⇒ ::String
Developer Preview: Unique name for the user.
Instance Attribute Details
#email ⇒ ::String
Returns Email for the member. This is required for creating the member.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 301 class Member include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role of this member in the space. module Role # This is used to indicate the user hasn't specified any value and the # user’s role will be determined upon joining the meetings between # 'contributor' and 'viewer' role depending on meeting configuration. More # details about viewer role # https://support.google.com/meet/answer/13658394?hl=en. ROLE_UNSPECIFIED = 0 # Co-host role. COHOST = 1 end end |
#name ⇒ ::String
Returns Identifier. Resource name of the member. Format: spaces/{space}/members/{member}.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 301 class Member include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role of this member in the space. module Role # This is used to indicate the user hasn't specified any value and the # user’s role will be determined upon joining the meetings between # 'contributor' and 'viewer' role depending on meeting configuration. More # details about viewer role # https://support.google.com/meet/answer/13658394?hl=en. ROLE_UNSPECIFIED = 0 # Co-host role. COHOST = 1 end end |
#role ⇒ ::Google::Apps::Meet::V2beta::Member::Role
Returns The meeting role assigned to the member.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 301 class Member include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role of this member in the space. module Role # This is used to indicate the user hasn't specified any value and the # user’s role will be determined upon joining the meetings between # 'contributor' and 'viewer' role depending on meeting configuration. More # details about viewer role # https://support.google.com/meet/answer/13658394?hl=en. ROLE_UNSPECIFIED = 0 # Co-host role. COHOST = 1 end end |
#user ⇒ ::String
Returns Developer Preview:
Unique name for the user. Interoperable with Admin SDK API and People API.
This will be empty for non google users. Setting both user and email in
request will result in error. Format: users/{user}.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 301 class Member include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role of this member in the space. module Role # This is used to indicate the user hasn't specified any value and the # user’s role will be determined upon joining the meetings between # 'contributor' and 'viewer' role depending on meeting configuration. More # details about viewer role # https://support.google.com/meet/answer/13658394?hl=en. ROLE_UNSPECIFIED = 0 # Co-host role. COHOST = 1 end end |