Class: Google::Apps::Meet::V2beta::Participant
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2beta::Participant
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2beta/resource.rb
Overview
User who attended or is attending a conference.
Instance Attribute Summary collapse
-
#anonymous_user ⇒ ::Google::Apps::Meet::V2beta::AnonymousUser
Anonymous user.
-
#earliest_start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#latest_end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#phone_user ⇒ ::Google::Apps::Meet::V2beta::PhoneUser
User calling from their phone.
-
#signedin_user ⇒ ::Google::Apps::Meet::V2beta::SignedinUser
Signed-in user.
Instance Attribute Details
#anonymous_user ⇒ ::Google::Apps::Meet::V2beta::AnonymousUser
Returns Anonymous user.
Note: The following fields are mutually exclusive: anonymous_user, signedin_user, phone_user. If a field in that set is populated, all other fields in the set will automatically be cleared.
372 373 374 375 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 372 class Participant include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#earliest_start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time when the participant first joined the meeting.
372 373 374 375 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 372 class Participant include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#latest_end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time when the participant left the meeting for the last time. This can be null if it's an active meeting.
372 373 374 375 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 372 class Participant include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
Returns Output only. Resource name of the participant.
Format: conferenceRecords/{conference_record}/participants/{participant}.
372 373 374 375 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 372 class Participant include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#phone_user ⇒ ::Google::Apps::Meet::V2beta::PhoneUser
Returns User calling from their phone.
Note: The following fields are mutually exclusive: phone_user, signedin_user, anonymous_user. If a field in that set is populated, all other fields in the set will automatically be cleared.
372 373 374 375 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 372 class Participant include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#signedin_user ⇒ ::Google::Apps::Meet::V2beta::SignedinUser
Returns Signed-in user.
Note: The following fields are mutually exclusive: signedin_user, anonymous_user, phone_user. If a field in that set is populated, all other fields in the set will automatically be cleared.
372 373 374 375 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 372 class Participant include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |