Class: Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::RecordingConfig
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::RecordingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2beta/resource.rb
Overview
Configuration related to recording in a meeting space.
Instance Attribute Summary collapse
-
#auto_recording_generation ⇒ ::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType
Defines whether a meeting space is automatically recorded when someone with the privilege to record joins the meeting.
Instance Attribute Details
#auto_recording_generation ⇒ ::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType
Returns Defines whether a meeting space is automatically recorded when someone with the privilege to record joins the meeting.
174 175 176 177 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 174 class RecordingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |