Class: Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::TranscriptionConfig
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::TranscriptionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/apps/meet/v2beta/resource.rb
Overview
Configuration related to transcription in a meeting space.
Instance Attribute Summary collapse
-
#auto_transcription_generation ⇒ ::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType
Defines whether the content of a meeting is automatically transcribed when someone with the privilege to transcribe joins the meeting.
Instance Attribute Details
#auto_transcription_generation ⇒ ::Google::Apps::Meet::V2beta::SpaceConfig::ArtifactConfig::AutoGenerationType
Returns Defines whether the content of a meeting is automatically transcribed when someone with the privilege to transcribe joins the meeting.
184 185 186 187 |
# File 'proto_docs/google/apps/meet/v2beta/resource.rb', line 184 class TranscriptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |