Class: Google::Apps::Meet::V2beta::SpacesService::Client
- Inherits:
-
Object
- Object
- Google::Apps::Meet::V2beta::SpacesService::Client
- Includes:
- Paths
- Defined in:
- lib/google/apps/meet/v2beta/spaces_service/client.rb
Overview
Client for the SpacesService service.
REST API for services dealing with spaces.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the SpacesService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the SpacesService Client instance.
-
#connect_active_conference(request, options = nil) {|response, operation| ... } ⇒ ::Google::Apps::Meet::V2beta::ConnectActiveConferenceResponse
Developer Preview: Broker a WebRTC connection to the active conference of a space.
-
#create_member(request, options = nil) {|response, operation| ... } ⇒ ::Google::Apps::Meet::V2beta::Member
Developer Preview: Create a member.
-
#create_space(request, options = nil) {|response, operation| ... } ⇒ ::Google::Apps::Meet::V2beta::Space
Creates a space.
-
#delete_member(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Developer Preview: Delete the member who was previously assigned roles in the space.
-
#end_active_conference(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Ends an active conference (if there's one).
-
#get_member(request, options = nil) {|response, operation| ... } ⇒ ::Google::Apps::Meet::V2beta::Member
Developer Preview: Get a member.
-
#get_space(request, options = nil) {|response, operation| ... } ⇒ ::Google::Apps::Meet::V2beta::Space
Gets details about a meeting space.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new SpacesService client object.
-
#list_members(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Apps::Meet::V2beta::Member>
Developer Preview: List members.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_space(request, options = nil) {|response, operation| ... } ⇒ ::Google::Apps::Meet::V2beta::Space
Updates details about a meeting space.
Methods included from Paths
#conference_record_path, #member_path, #space_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new SpacesService client object.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 143 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/apps/meet/v2beta/service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @spaces_service_stub = ::Gapic::ServiceStub.new( ::Google::Apps::Meet::V2beta::SpacesService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @spaces_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the SpacesService Client class.
See Configuration for a description of the configuration fields.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 62 def self.configure @configure ||= begin namespace = ["Google", "Apps", "Meet", "V2beta"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_space.timeout = 60.0 default_config.rpcs.get_space.timeout = 60.0 default_config.rpcs.get_space.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_space.timeout = 60.0 default_config.rpcs.end_active_conference.timeout = 60.0 default_config.rpcs.create_member.timeout = 60.0 default_config.rpcs.get_member.timeout = 60.0 default_config.rpcs.list_members.timeout = 60.0 default_config.rpcs.delete_member.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the SpacesService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
113 114 115 116 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 113 def configure yield @config if block_given? @config end |
#connect_active_conference(request, options = nil) ⇒ ::Google::Apps::Meet::V2beta::ConnectActiveConferenceResponse #connect_active_conference(name: nil, offer: nil) ⇒ ::Google::Apps::Meet::V2beta::ConnectActiveConferenceResponse
Developer Preview: Broker a WebRTC connection to the active conference of a space.
On success, clients must use the resulting SDP (Session Description Protocol) answer to establish a WebRTC connection. Once connected, additional functionality is available across WebRTC data channels.
See Meet Media API overview for more details about this connection.
546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 546 def connect_active_conference request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2beta::ConnectActiveConferenceRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.connect_active_conference..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.connect_active_conference.timeout, metadata: , retry_policy: @config.rpcs.connect_active_conference.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @spaces_service_stub.call_rpc :connect_active_conference, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_member(request, options = nil) ⇒ ::Google::Apps::Meet::V2beta::Member #create_member(parent: nil, member: nil) ⇒ ::Google::Apps::Meet::V2beta::Member
Developer Preview: Create a member.
This API supports the fields parameter in
SystemParameterContext.
When the fields parameter is omitted, this API response will default to
"name,email,role,user".
735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 735 def create_member request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2beta::CreateMemberRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_member..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_member.timeout, metadata: , retry_policy: @config.rpcs.create_member.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @spaces_service_stub.call_rpc :create_member, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_space(request, options = nil) ⇒ ::Google::Apps::Meet::V2beta::Space #create_space(space: nil) ⇒ ::Google::Apps::Meet::V2beta::Space
Creates a space.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 250 def create_space request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2beta::CreateSpaceRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_space..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_space.timeout, metadata: , retry_policy: @config.rpcs.create_space.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @spaces_service_stub.call_rpc :create_space, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_member(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_member(name: nil) ⇒ ::Google::Protobuf::Empty
Developer Preview: Delete the member who was previously assigned roles in the space.
1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 1016 def delete_member request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2beta::DeleteMemberRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_member..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_member.timeout, metadata: , retry_policy: @config.rpcs.delete_member.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @spaces_service_stub.call_rpc :delete_member, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#end_active_conference(request, options = nil) ⇒ ::Google::Protobuf::Empty #end_active_conference(name: nil) ⇒ ::Google::Protobuf::Empty
Ends an active conference (if there's one).
For an example, see End active conference.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 642 def end_active_conference request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2beta::EndActiveConferenceRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.end_active_conference..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.end_active_conference.timeout, metadata: , retry_policy: @config.rpcs.end_active_conference.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @spaces_service_stub.call_rpc :end_active_conference, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_member(request, options = nil) ⇒ ::Google::Apps::Meet::V2beta::Member #get_member(name: nil) ⇒ ::Google::Apps::Meet::V2beta::Member
Developer Preview: Get a member.
This API supports the fields parameter in
SystemParameterContext.
When the fields parameter is omitted, this API response will default to
"name,email,role,user".
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 826 def get_member request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2beta::GetMemberRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_member..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_member.timeout, metadata: , retry_policy: @config.rpcs.get_member.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @spaces_service_stub.call_rpc :get_member, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_space(request, options = nil) ⇒ ::Google::Apps::Meet::V2beta::Space #get_space(name: nil) ⇒ ::Google::Apps::Meet::V2beta::Space
Gets details about a meeting space.
For an example, see Get a meeting space.
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 348 def get_space request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2beta::GetSpaceRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_space..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_space.timeout, metadata: , retry_policy: @config.rpcs.get_space.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @spaces_service_stub.call_rpc :get_space, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_members(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Apps::Meet::V2beta::Member> #list_members(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Apps::Meet::V2beta::Member>
Developer Preview: List members.
This API supports the fields parameter in
SystemParameterContext.
When the fields parameter is omitted this API response will default to
"name,email,role,user".
928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 928 def list_members request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2beta::ListMembersRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_members..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_members.timeout, metadata: , retry_policy: @config.rpcs.list_members.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @spaces_service_stub.call_rpc :list_members, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @spaces_service_stub, :list_members, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
199 200 201 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 199 def logger @spaces_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
123 124 125 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 123 def universe_domain @spaces_service_stub.universe_domain end |
#update_space(request, options = nil) ⇒ ::Google::Apps::Meet::V2beta::Space #update_space(space: nil, update_mask: nil) ⇒ ::Google::Apps::Meet::V2beta::Space
Updates details about a meeting space.
For an example, see Update a meeting space.
443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/google/apps/meet/v2beta/spaces_service/client.rb', line 443 def update_space request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Apps::Meet::V2beta::UpdateSpaceRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_space..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Apps::Meet::V2beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.space&.name header_params["space.name"] = request.space.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_space.timeout, metadata: , retry_policy: @config.rpcs.update_space.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @spaces_service_stub.call_rpc :update_space, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |